@@ -9,11 +9,13 @@
 #
 # Cross compile Linux from macOS:
 # * brew install FiloSottile/musl-cross/musl-cross
+#
+# Note config in .cargo/config.toml for this to work.
 
 set -eu -o pipefail
 
 # List available SDKs using "xcodebuild -showsdks"
-CROSSBUILD_MACOS_SDK="macosx15.4"
+CROSSBUILD_MACOS_SDK="macosx26.0"
 
 # Git hooks can use this variable to avoid duplicating the CI work we do in here
 # anyway.
@@ -62,8 +64,8 @@ cat <<EOM
 Please consider updating the screenshot in README.md before releasing.
 
 Scale your window to 92x28, then:
-* Get the moar source code: <https://github.com/walles/moar>
-* In the moar source code, do: "git show 9c91399309"
+* Get the moor source code: <https://github.com/walles/moor>
+* In the moor source code, do: "git show 9c91399309"
 
 Answer yes at this prompt to verify that the Output section is complete.
 EOM
@@ -172,6 +174,13 @@ rustup target add x86_64-unknown-linux-musl
 cargo build --release --target=x86_64-unknown-linux-musl
 $LIVE && cp "target/x86_64-unknown-linux-musl/release/riff" "riff-$NEW_VERSION_NUMBER-x86_64-linux"
 
+# Build a Linux-ARM64 binary on macOS
+#
+# From: https://timryan.org/2018/07/27/cross-compiling-linux-binaries-from-macos.html
+rustup target add aarch64-unknown-linux-musl
+cargo build --release --target=aarch64-unknown-linux-musl
+$LIVE && cp "target/aarch64-unknown-linux-musl/release/riff" "riff-$NEW_VERSION_NUMBER-aarch64-linux"
+
 # Build a Windows binary on macOS
 #
 # From: https://gist.github.com/Mefistophell/9787e1b6d2d9441c16d2ac79d6a505e6
