@@ -6,6 +6,8 @@ use crate::io::ErrorKind;
 use crate::lines_highlighter::{LineAcceptance, LinesHighlighter};
 use crate::plusminus_header_highlighter::PlusMinusHeaderHighlighter;
 use crate::refiner::Formatter;
+use crate::rename_highlighter::RenameHighlighter;
+use once_cell::sync::Lazy;
 use std::io::{self, BufWriter, Write};
 use std::process::{self, exit};
 use std::sync::mpsc::{sync_channel, Receiver, SyncSender};
@@ -15,8 +17,8 @@ use std::thread::{self, JoinHandle};
 use crate::{constants::*, string_future::StringFuture};
 use threadpool::ThreadPool;
 
-lazy_static! {
-    static ref STATIC_HEADER_PREFIXES: Vec<(&'static str, &'static str)> = vec![
+static STATIC_HEADER_PREFIXES: Lazy<Vec<(&'static str, &'static str)>> = Lazy::new(|| {
+    vec![
         ("diff ", FAINT),
         ("index ", FAINT),
         ("Binary files ", BOLD),
@@ -27,17 +29,16 @@ lazy_static! {
         ("similarity index ", FAINT),
         ("new file mode ", FAINT),
         ("deleted file mode ", FAINT),
-    ];
+    ]
+});
 
-    /// This is the `\ No newline at end of file` string. But since it can come
-    /// in not-English as well as English, we take it from the input and store it
-    /// in this variable. None means we don't know yet.
-    ///
-    /// See also: https://github.com/walles/riff/issues/39
-    pub(crate) static ref NO_EOF_NEWLINE_MARKER_HOLDER: std::sync::Arc<
-        std::sync::Mutex<std::option::Option<std::string::String>>,
-    > = Arc::new(Mutex::<Option<String>>::new(None));
-}
+/// This is the `\ No newline at end of file` string. But since it can come in
+/// not-English as well as English, we take it from the input and store it in
+/// this variable. None means we don't know yet.
+///
+/// See also: https://github.com/walles/riff/issues/39
+pub(crate) static NO_EOF_NEWLINE_MARKER_HOLDER: Lazy<Arc<Mutex<Option<String>>>> =
+    Lazy::new(|| Arc::new(Mutex::<Option<String>>::new(None)));
 
 #[must_use]
 fn get_fixed_highlight(line: &str) -> Option<&str> {
@@ -119,7 +120,7 @@ impl Drop for LineCollector {
                 .consume_eof(&self.thread_pool);
             if let Err(error) = result {
                 self.lines_highlighter = None;
-                eprintln!("ERROR at end of input: {}", error);
+                eprintln!("ERROR at end of input: {error}");
                 process::exit(1);
             }
 
@@ -242,8 +243,7 @@ impl LineCollector {
         let line = String::from_utf8_lossy(&line).to_string();
         self.print_queue_putter
             .send(StringFuture::from_string(format!(
-                "{}{}{}",
-                PARSE_ERROR, line, NORMAL
+                "{PARSE_ERROR}{line}{NORMAL}"
             )))
             .unwrap();
 
@@ -304,7 +304,9 @@ impl LineCollector {
             }
         }
 
-        if let Some(hunk_highlighter) = HunkLinesHighlighter::from_line(&line, self.formatter) {
+        if let Some(hunk_highlighter) =
+            HunkLinesHighlighter::from_line(&line, self.formatter.clone())
+        {
             self.drain_plain();
             self.lines_highlighter = Some(Box::new(hunk_highlighter));
             return Ok(());
@@ -322,6 +324,12 @@ impl LineCollector {
             return Ok(());
         }
 
+        if let Some(rename_highlighter) = RenameHighlighter::from_line(&line) {
+            self.drain_plain();
+            self.lines_highlighter = Some(Box::new(rename_highlighter));
+            return Ok(());
+        }
+
         if line.starts_with("diff") {
             self.diff_seen = true;
         }
@@ -340,7 +348,7 @@ impl LineCollector {
 
         if line.starts_with('\\') {
             // "\ No newline at end of file"
-            self.consume_plain_line(&format!("{}{}{}", NO_EOF_NEWLINE_COLOR, line, NORMAL));
+            self.consume_plain_line(&format!("{NO_EOF_NEWLINE_COLOR}{line}{NORMAL}"));
             return Ok(());
         }
 
